Crate riscv_rt_macros

Crate riscv_rt_macros 

Macros

default_start_trap
Generates _default_start_trap function in assembly. If no _start_trap function is defined, the linker will use this function as the default.
llvm_arch_patch
Temporary patch macro to deal with LLVM bug
loop_asm
Loops an asm expression n times.
loop_global_asm
Loops a global_asm expression n times.

Attribute Macros

core_interrupt
Attribute to declare a core interrupt handler.
entry
Attribute to declare the entry point of the program
exception
Attribute to declare an exception handler.
external_interrupt
Attribute to declare an external interrupt handler.
post_init
Attribute to mark which function will be called before jumping to the entry point. You must enable the post-init feature in the riscv-rt crate to use this macro.
pre_initDeprecated
Attribute to mark which function will be called at the beginning of the reset handler. You must enable the pre_init feature in the riscv-rt crate to use this macro.