Attribute to mark which function will be called before jumping to the entry point.
You must enable the post-init feature in the riscv-rt crate to use this macro.
Attribute to mark which function will be called at the beginning of the reset handler.
You must enable the pre_init feature in the riscv-rt crate to use this macro.